register_explicit

Function register_explicit 

pub fn register_explicit<T>()
where T: ServerFn + 'static, <T as ServerFn>::Server: Server<<T as ServerFn>::Error, <T as ServerFn>::InputStreamError, <T as ServerFn>::OutputStreamError, Request = Request<Body>, Response = Response<Body>>,
Available on crate feature axum-no-default only.
Explicitly register a server function. This is only necessary if you are running the server in a WASM environment (or a rare environment that the inventory crate won’t work in.).